<?php

namespace App\Store\Controllers;

use App\Models\MerchantStore;
use App\Admin\Renderable\MerchantStoreSkuList;
use App\Models\Good;
use App\Models\StoreGoodsCategory;
use App\Models\StoreGoodsTag;
use Dcat\Admin\Admin;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Show;
use Dcat\Admin\Http\Controllers\AdminController;

class MerchatGoodsStoreController extends AdminController
{
    /**
     * Make a grid builder.
     *
     * @return Grid
     */
    protected function grid()
    {
        return Grid::make(MerchantStore::with(['goods', 'merchant']), function (Grid $grid) {
            $grid->addTableClass(['table-text-center']);
            $grid->model()->where(['merchant_id' => Admin::user()->id])->orderBy('created_at', 'DESC');
            $grid->column('id')->sortable();
            $grid->column('goods_sn', '商品编号');
            $grid->column('goods.cover_img', '商品图片')->image('', 100, 100);
            $grid->column('goods.goods_name', '商品名称');
            $grid->column('attr', '商品规格')->expand(function (Grid\Displayers\Expand $expand) {
                $expand->button('查看');
                return MerchantStoreSkuList::make(['mgs_id' => $this->id]);
            })->width(100);
            $grid->column('store', '库存');

            $grid->setDialogFormDimensions('70%', '90%');
            $grid->enableDialogCreate();
            $grid->showQuickEditButton();
            $grid->disableCreateButton();
            $grid->disableEditButton();
            $grid->disableViewButton();
            $grid->disableActions();
            // $grid->simplePaginate();
            $grid->disableFilterButton();
            $grid->quickSearch('goods.goods_name')->placeholder('搜索商品');
            // $grid->filter(function (Grid\Filter $filter) {
            //     $filter->equal('id');
            // });
        });
    }

    /**
     * Make a show builder.
     *
     * @param mixed $id
     *
     * @return Show
     */
    protected function detail($id)
    {
        return Show::make($id, new StoreGood(), function (Show $show) {
            $show->field('id');
            $show->field('title');
            $show->field('tags');
            $show->field('price');
            $show->field('sale_price');
            $show->field('small_cover');
            $show->field('cover');
            $show->field('category_id');
            $show->field('intro');
            $show->field('look_num');
            $show->field('inventory');
            $show->field('created_at');
            $show->field('updated_at');
        });
    }

    /**
     * Make a form builder.
     *
     * @return Form
     */
    protected function form()
    {
        return Form::make(new StoreGood(), function (Form $form) {
            if ($form->isCreating()) {
                $form->hidden('store_id')->value(Admin::user()->id);
            }
            $form->text('title');
            $form->multipleSelect('tags')
                ->options(StoreGoodsTag::where(['store_id' => Admin::user()->id])->get()->pluck('title', 'id'))
                ->saving(function ($value) {
                    return $value ? json_encode($value) : null;
                });
            $form->currency('price')->symbol('¥');
            $form->currency('sale_price')->symbol('¥');
            $form->image('small_cover')->accept('jpg,jpeg,png')
                ->maxSize(4096)
                ->url('upload/store')
                ->help('仅支持jpg、jpeg、png格式图片上传')
                ->autoUpload();
            $form->image('cover')->accept('jpg,jpeg,png')
                ->maxSize(4096)
                ->url('upload/store')
                ->help('仅支持jpg、jpeg、png格式图片上传')
                ->autoUpload();
            $form->select('category_id')
                ->options(StoreGoodsCategory::where(['store_id' => Admin::user()->id])->get()->pluck('title', 'id'))
                ->default(0)->required();
            $form->editor('intro')->imageUrl('upload/store')
                ->height(400);

            $form->number('inventory');

            $form->disableDeleteButton();
            $form->disableEditingCheck();
            $form->disableViewButton();
            $form->disableViewCheck();
            $form->disableCreatingCheck();
        });
    }
}
